@@ -2,7 +2,7 @@
 # Copyright 2020, Xiaomi.
 # All rights reserved.
 # Author: huyumei@xiaomi.com
-# 
+#
 
 from talos.client.TalosClientConfig import TalosClientConfig
 from talos.thrift.auth.ttypes import Credential
@@ -10,6 +10,7 @@ from talos.thrift.common.ttypes import Version
 from talos.thrift.topic import TopicService
 from talos.thrift.message import MessageService
 from talos.thrift.consumer import ConsumerService
+from talos.thrift.quota import QuotaService
 from talos.client.TalosErrors import InvalidArgumentError
 from talos.client.Constants import Constants
 from talos.thrift.protocol.TCompactProtocol import TCompactProtocol
@@ -60,6 +61,11 @@ class ConsumerClient:
         iprot = TCompactProtocol(self.talosHttpClient)
         return ConsumerService.Client(iprot).updateOffset(request)
 
+    def get_worker_id(self, request=None):
+        self.talosHttpClient.set_query_string("type=getWorkerId")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return ConsumerService.Client(iprot).getWorkerId(request).workerId
+
 
 class TopicClient:
     talosHttpClient = TalosHttpClient
@@ -67,6 +73,11 @@ class TopicClient:
     def __init__(self, talosHttpClient=None):
         self.talosHttpClient = talosHttpClient
 
+    def create_topic(self, request=None):
+        self.talosHttpClient.set_query_string("type=createTopic")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return TopicService.Client(iprot).createTopic(request)
+
     def get_describe_info(self, request=None):
         self.talosHttpClient.set_query_string("type=getDescribeInfo")
         iprot = TCompactProtocol(self.talosHttpClient)
@@ -77,6 +88,37 @@ class TopicClient:
         iprot = TCompactProtocol(self.talosHttpClient)
         return TopicService.Client(iprot).getTopicAttribute(request)
 
+    def delete_topic(self, request=None):
+        self.talosHttpClient.set_query_string("type=deleteTopic")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return TopicService.Client(iprot).deleteTopic(request)
+
+    def change_topic_attribute(self, request=None):
+        self.talosHttpClient.set_query_string("type=changeTopicAttribute")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return TopicService.Client(iprot).changeTopicAttribute(request)
+
+    def list_topics(self):
+        self.talosHttpClient.set_query_string("type=listTopics")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return TopicService.Client(iprot).listTopics().topicInfos
+
+    def set_permission(self, request=None):
+        assert request.permission > 0
+        self.talosHttpClient.set_query_string("type=setPermission")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        TopicService.Client(iprot).setPermission(request)
+
+    def revoke_permission(self, request=None):
+        self.talosHttpClient.set_query_string("type=revokePermission")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        TopicService.Client(iprot).setPermission(request)
+
+    def list_permission(self, request=None):
+        self.talosHttpClient.set_query_string("type=listPermission")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return TopicService.Client(iprot).listPermission(request).permissions
+
 
 class MessageClient:
     talosHttpClient = TalosHttpClient
@@ -94,6 +136,42 @@ class MessageClient:
         iprot = TCompactProtocol(self.talosHttpClient)
         return MessageService.Client(iprot).putMessage(request)
 
+    def get_topic_offset(self, request=None):
+        self.talosHttpClient.set_query_string("type=getTopicOffset")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return MessageService.Client(iprot).getTopicOffset(request).offsetInfoList
+
+    def get_partition_offset(self, request=None):
+        self.talosHttpClient.set_query_string("type=getPartitionOffset")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return MessageService.Client(iprot).getPartitionOffset(request).offsetInfo
+
+    def get_schedule_info(self, request=None):
+        self.talosHttpClient.set_query_string("type=getScheduleInfo")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return MessageService.Client(iprot).getScheduleInfo(request).scheduleInfo
+
+
+class QuotaClient:
+    talosHttpClient = TalosHttpClient
+
+    def __init__(self, talosHttpClient=None):
+        self.talosHttpClient = talosHttpClient
+
+    def apply_quota(self, request=None):
+        self.talosHttpClient.set_query_string("type=applyQuota")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        QuotaService.Client(iprot).applyQuota(request)
+
+    def revoke_quota(self, request=None):
+        self.talosHttpClient.set_query_string("type=revokeQuota")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return QuotaService.Client(iprot).revokeQuota(request)
+
+    def list_quota(self):
+        self.talosHttpClient.set_query_string("type=listQuota")
+        iprot = TCompactProtocol(self.talosHttpClient)
+        return QuotaService.Client(iprot).listQuota()
 
 class TalosClientFactory:
     logger = logging.getLogger("TalosClientFactory")
